@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -79,7 +79,17 @@ $table = (new CTableInfo())
 $current_time = time();
 
 foreach ($data['hosts'] as $host) {
-	$interface = reset($host['interfaces']);
+	// Select an interface from the list with highest priority.
+	$interface = null;
+	foreach ([INTERFACE_TYPE_AGENT, INTERFACE_TYPE_SNMP, INTERFACE_TYPE_JMX, INTERFACE_TYPE_IPMI] as $interface_type) {
+		$host_interfaces = array_filter($host['interfaces'], function($host_interface) use($interface_type) {
+			return $host_interface['type'] == $interface_type;
+		});
+		if ($host_interfaces) {
+			$interface = reset($host_interfaces);
+			break;
+		}
+	}
 
 	$description = [];
 
@@ -143,26 +153,38 @@ foreach ($data['hosts'] as $host) {
 			break;
 		}
 
-		$caption = [
-			(new CLink(
-				CHtml::encode($template['name']), 'templates.php?form=update&templateid='.$template['templateid']
-			))
-				->addClass(ZBX_STYLE_LINK_ALT)
-				->addClass(ZBX_STYLE_GREY)
-		];
-
-		$parentTemplates = $data['templates'][$template['templateid']]['parentTemplates'];
-		if ($parentTemplates) {
-			order_result($parentTemplates, 'name');
-
-			$caption[] = ' (';
-			foreach ($parentTemplates as $parentTemplate) {
-				$caption[] = (new CLink(
-					CHtml::encode($parentTemplate['name']),
-					'templates.php?form=update&templateid='.$parentTemplate['templateid']
+		if (array_key_exists($template['templateid'], $data['writable_templates'])) {
+			$caption = [
+				(new CLink(
+					CHtml::encode($template['name']), 'templates.php?form=update&templateid='.$template['templateid']
 				))
 					->addClass(ZBX_STYLE_LINK_ALT)
-					->addClass(ZBX_STYLE_GREY);
+					->addClass(ZBX_STYLE_GREY)
+			];
+		}
+		else {
+			$caption = [
+				(new CSpan(CHtml::encode($template['name'])))->addClass(ZBX_STYLE_GREY)
+			];
+		}
+
+		$parent_templates = $data['templates'][$template['templateid']]['parentTemplates'];
+
+		if ($parent_templates) {
+			order_result($parent_templates, 'name');
+			$caption[] = ' (';
+
+			foreach ($parent_templates as $parent_template) {
+				if (array_key_exists($parent_template['templateid'], $data['writable_templates'])) {
+					$caption[] = (new CLink(CHtml::encode($parent_template['name']),
+						'templates.php?form=update&templateid='.$parent_template['templateid']
+					))
+						->addClass(ZBX_STYLE_LINK_ALT)
+						->addClass(ZBX_STYLE_GREY);
+				}
+				else {
+					$caption[] = (new CSpan(CHtml::encode($parent_template['name'])))->addClass(ZBX_STYLE_GREY);
+				}
 				$caption[] = ', ';
 			}
 			array_pop($caption);
