@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 ** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 **/
 
+
 require_once dirname(__FILE__).'/js/configuration.item.list.js.php';
 
 if (empty($this->data['hostid'])) {
@@ -77,6 +78,8 @@ $this->data['itemTriggers'] = CMacrosResolverHelper::resolveTriggerExpressions($
 	'sources' => ['expression', 'recovery_expression']
 ]);
 
+$update_interval_parser = new CUpdateIntervalParser(['usermacros' => true]);
+
 foreach ($this->data['items'] as $item) {
 	// description
 	$description = [];
@@ -104,6 +107,21 @@ foreach ($this->data['items'] as $item) {
 		$description[] = NAME_DELIMITER;
 	}
 
+	if ($item['type'] == ITEM_TYPE_DEPENDENT) {
+		if ($item['master_item']['type'] == ITEM_TYPE_HTTPTEST) {
+			$description[] = CHtml::encode($item['master_item']['name_expanded']);
+		}
+		else {
+			$description[] = (new CLink(CHtml::encode($item['master_item']['name_expanded']),
+				'?form=update&hostid='.$item['hostid'].'&itemid='.$item['master_item']['itemid']
+			))
+				->addClass(ZBX_STYLE_LINK_ALT)
+				->addClass(ZBX_STYLE_TEAL);
+		}
+
+		$description[] = NAME_DELIMITER;
+	}
+
 	$description[] = new CLink(CHtml::encode($item['name_expanded']),
 		'?form=update&hostid='.$item['hostid'].'&itemid='.$item['itemid']
 	);
@@ -220,7 +238,8 @@ foreach ($this->data['items'] as $item) {
 		$triggerInfo = SPACE;
 	}
 
-	// if item type is 'Log' we must show log menu
+	$item_menu = CMenuPopupHelper::getDependentItem($item['itemid'], $item['hostid'], $item['name']);
+
 	if (in_array($item['value_type'], [ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_TEXT])) {
 		$triggers = [];
 
@@ -241,26 +260,38 @@ foreach ($this->data['items'] as $item) {
 			];
 		}
 
-		$menuIcon = (new CSpan(
-			(new CButton(null))
-				->addClass(ZBX_STYLE_ICON_WZRD_ACTION)
-				->setMenuPopup(CMenuPopupHelper::getTriggerLog($item['itemid'], $item['name'], $triggers))
-		))->addClass(ZBX_STYLE_REL_CONTAINER);
+		$trigger_menu = CMenuPopupHelper::getTriggerLog($item['itemid'], $item['name'], $triggers);
+		$trigger_menu['dependent_items'] = $item_menu;
+		$item_menu = $trigger_menu;
 	}
-	else {
-		$menuIcon = '';
+
+	if (in_array($item['value_type'], [ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_TEXT])) {
+		$item['trends'] = '';
 	}
 
+	// Hide zeroes for trapper, SNMP trap and dependent items.
+	if ($item['type'] == ITEM_TYPE_TRAPPER || $item['type'] == ITEM_TYPE_SNMPTRAP
+			|| $item['type'] == ITEM_TYPE_DEPENDENT) {
+		$item['delay'] = '';
+	}
+	elseif ($update_interval_parser->parse($item['delay']) == CParser::PARSE_SUCCESS) {
+		$item['delay'] = $update_interval_parser->getDelay();
+	}
+
+	$wizard = (new CSpan(
+		(new CButton(null))->addClass(ZBX_STYLE_ICON_WZRD_ACTION)->setMenuPopup($item_menu)
+	))->addClass(ZBX_STYLE_REL_CONTAINER);
+
 	$itemTable->addRow([
 		new CCheckBox('group_itemid['.$item['itemid'].']', $item['itemid']),
-		$menuIcon,
+		$wizard,
 		empty($this->data['filter_hostid']) ? $item['host'] : null,
 		$description,
 		$triggerInfo,
 		CHtml::encode($item['key_']),
-		($item['delay'] !== '') ? convertUnitsS($item['delay']) : '',
-		$item['history']._x('d', 'day short'),
-		($item['trends'] !== '') ? $item['trends']._x('d', 'day short') : '',
+		$item['delay'],
+		$item['history'],
+		$item['trends'],
 		item_type2str($item['type']),
 		CHtml::encode($item['applications_list']),
 		$status,
